summaryrefslogtreecommitdiffstats
path: root/config
diff options
context:
space:
mode:
authorThomas Backlund <tmb@mageia.org>2015-11-22 19:42:59 +0200
committerThomas Backlund <tmb@mageia.org>2015-11-22 19:42:59 +0200
commit933857e1cc701829b93d35649a32e7cc3df36810 (patch)
tree3be36ea13657dd58f52f6517e5894fc32dec607f /config
parent5723f6a80d2a01582d497152a7f973fcd3bb43b5 (diff)
downloaddraklive-config-933857e1cc701829b93d35649a32e7cc3df36810.tar
draklive-config-933857e1cc701829b93d35649a32e7cc3df36810.tar.gz
draklive-config-933857e1cc701829b93d35649a32e7cc3df36810.tar.bz2
draklive-config-933857e1cc701829b93d35649a32e7cc3df36810.tar.xz
draklive-config-933857e1cc701829b93d35649a32e7cc3df36810.zip
KDE4 is replaced by PLASMA5
Diffstat (limited to 'config')
-rw-r--r--config/auto_inst.cfg.pl34
-rw-r--r--config/live.cfg20
2 files changed, 27 insertions, 27 deletions
diff --git a/config/live.cfg b/config/live.cfg
index 182685a..823e8b4 100644
--- a/config/live.cfg
+++ b/config/live.cfg
@@ -63,12 +63,12 @@ my $_l = {
[ 'files/mga_rpms/GNOME/x86_64/mga_rpms', '/var/local/mga_rpms' ],
),
),
- if_($live->{settings}{desktop} eq 'KDE4',
+ if_($live->{settings}{desktop} eq 'PLASMA5',
if_($live->{settings}{arch} eq 'i586',
- [ 'files/mga_rpms/KDE4/i586/mga_rpms', '/var/local/mga_rpms' ],
+ [ 'files/mga_rpms/PLASMA5/i586/mga_rpms', '/var/local/mga_rpms' ],
),
if_($live->{settings}{arch} eq 'x86_64',
- [ 'files/mga_rpms/KDE4/x86_64/mga_rpms', '/var/local/mga_rpms' ],
+ [ 'files/mga_rpms/PLASMA5/x86_64/mga_rpms', '/var/local/mga_rpms' ],
),
),
@@ -97,7 +97,7 @@ my $_l = {
if_($live->{settings}{desktop} eq 'GNOME',
[ 'files/draklive-install.d/run.d/gdm-permissions.sh', '/etc/draklive-install.d/run.d/gdm-permissions.sh', { mode => 755 } ]
),
- if_($live->{settings}{desktop} eq 'KDE4',
+ if_($live->{settings}{desktop} eq 'PLASMA5',
[ 'files/draklive-install.d/run.d/generate-gtk-icon-cache.sh', '/etc/draklive-install.d/run.d/generate-gtk-icon-cache.sh', { mode => 755 } ]
),
#- sysconfig files for first boot
@@ -197,7 +197,7 @@ my $_l = {
#- used by liveusb-rw
"/usr/sbin/compute-i18n-list.pl --ooo=${ooo_version}",
if_($live->{settings}{product} =~ /liveusb-rw/i && $live->{settings}{desktop} =~ /^KDE/,
- #- FIXME: check if still valid for KDE4
+ #- FIXME: check if still valid for PLASMA5
"perl -pi -e 's,kde[/-]KMail,mageia-mozilla-thunderbird,' /var/lib/mageia/kde-profiles/common/share/config/kickerrc"
),
#- fix user perms for copied files
@@ -215,7 +215,7 @@ my $_l = {
#- adduser seems to create a sparse lastlog with a slot for all available users
#- which can be huge
'> /var/log/lastlog',
- if_($live->{settings}{desktop} eq 'KDE4',
+ if_($live->{settings}{desktop} eq 'PLASMA5',
"rm -f /usr/share/icons/*/icon-theme.cache",
"cp -a /etc/akonadi/mysql-global.conf /etc/akonadi/mysql-global-standard.conf",
"cp /etc/akonadi/mysql-global-mobile.conf /etc/akonadi/mysql-global.conf",
@@ -297,8 +297,8 @@ my $_l = {
extra_modules => [ qw(vfat sd_mod usb_storage uhci_hcd ohci_hcd ehci_hcd xhci_hcd) ],
files => [
if_($live->{settings}{arch} eq 'x86_64',
- if_($live->{settings}{desktop} eq 'KDE4',
- [ 'files/UEFI/KDE4/*', '' ],
+ if_($live->{settings}{desktop} eq 'PLASMA5',
+ [ 'files/UEFI/PLASMA5/*', '' ],
),
if_($live->{settings}{desktop} eq 'GNOME',
[ 'files/UEFI/GNOME/*', '' ],
@@ -315,8 +315,8 @@ my $_l = {
extra_modules => [ qw(vfat sd_mod usb_storage uhci_hcd ohci_hcd ehci_hcd xhci_hcd) ],
files => [
if_($live->{settings}{arch} eq 'x86_64',
- if_($live->{settings}{desktop} eq 'KDE4',
- [ 'files/UEFI/KDE4/*', '' ],
+ if_($live->{settings}{desktop} eq 'PLASMA5',
+ [ 'files/UEFI/PLASMA5/*', '' ],
),
if_($live->{settings}{desktop} eq 'GNOME',
[ 'files/UEFI/GNOME/*', '' ],
diff --git a/config/auto_inst.cfg.pl b/config/auto_inst.cfg.pl
index 5665f75..e555d9c 100644
--- a/config/auto_inst.cfg.pl
+++ b/config/auto_inst.cfg.pl
@@ -9,7 +9,7 @@ my $distro_release = 'Default';
my $distro_config = lc($distro_release);
my @desktops = split(/\|/, $ENV{DRAKLIVE_DESKTOP});
-my $has_kde4 = member('KDE4', @desktops);
+my $has_plasma5 = member('PLASMA5', @desktops);
my $has_gnome = member('GNOME', @desktops);
my $has_xfce = member('xfce4', @desktops);
my $has_lxde = member('LXDE', @desktops);
@@ -48,7 +48,7 @@ $o = {
qw(EDITORS TERMINALS TEXT_TOOLS SHELLS FILE_TOOLS),
# system
qw(SYSTEM MINIMAL_DOCS X ACCESSIBILITY THEMES),
- if_($has_kde4, qw(KDE)),
+ if_($has_plasma5, qw(KDE)),
if_($has_gnome, qw(GNOME)),
if_($has_xfce, qw(XFCE)),
if_($has_lxde, qw(LXDE)),
@@ -83,7 +83,7 @@ $o = {
'/^libatlas3-/',
if_($ENV{DRAKLIVE_PRODUCT} =~ /LiveCD/i,
# kde livecd is too fat
- if_($has_kde4,
+ if_($has_plasma5,
'imagemagick', '/^kipi-plugins/', 'gimp',
'amarok', 'amarok-utils', 'nimbus-icon-theme',
'/^libkf5/', 'mageia-doc-mcc-en', 'bind-utils', 'mc', 'openssh-server',
@@ -145,7 +145,7 @@ $o = {
'/^libreoffice-help/',
'libreoffice-base',
'/^nvidia.*-doc-html/',
- if_($has_kde4,
+ if_($has_plasma5,
'liblm_sensors3', 'xpdf-common', 'htdig', 'mirrordir', 'acr38u',
'ekiga',
'kdeaccessibility4',
@@ -169,24 +169,24 @@ $o = {
),
#- bluez-pin provide
- if_(!$has_kde4, 'kbluetooth'),# 'plasma-applet-kimpanel-backend-ibus'),
+ if_(!$has_plasma5, 'kbluetooth'),# 'plasma-applet-kimpanel-backend-ibus'),
- if_(!$has_kde4, 'compiz-decorator-kde4'), #- provides compiz-decorator
- if_(!$has_kde4, 'pinentry-qt4'), #- qt4 app
+ if_(!$has_plasma5, 'compiz-decorator-kde4'), #- provides compiz-decorator
+ if_(!$has_plasma5, 'pinentry-qt4'), #- qt4 app
'/noatun/', #- prefer amarok
'rxvt',
if_($ENV{DRAKLIVE_PRODUCT} =~ /guadec/i, 'rfbdrake'),
- if_($has_kde4, 'gdb'), #- suggested by one of the kde4 base package
+ if_($has_plasma5, 'gdb'), #- suggested by one of the kde4 base package
- #exclude some packages that are too big from the KDE4 Live CD
+ #exclude some packages that are too big from the PLASMA5 Live CD
if_($ENV{DRAKLIVE_PRODUCT} !~ /liveusb-rw/i,
- if_($has_kde4, 'digikam'),
- if_($has_kde4, 'ufraw-gimp'),
- if_($has_kde4, 'marble-common'),
- if_($has_kde4, 'p7zip'),
- #if_($has_kde4, 'thunderbird'), #- we have kmail
+ if_($has_plasma5, 'digikam'),
+ if_($has_plasma5, 'ufraw-gimp'),
+ if_($has_plasma5, 'marble-common'),
+ if_($has_plasma5, 'p7zip'),
+ #if_($has_plasma5, 'thunderbird'), #- we have kmail
if_($has_gnome, 'thunderbird', 'pan'), #- we have evolution
'cpqarrayd',
),
@@ -231,7 +231,7 @@ $o = {
if_($ENV{DRAKLIVE_REGION} eq 'int', 'ardour', 'ardour3', 'lftp', 'lm_sensors', 'kscd', 'tvtime', 'kamera', '/^plasma-applet-system-monitor-/', 'dragon', 'k3b'),
],
'default_packages' => [
- if_($has_kde4, "$distro_config-kde4-config"),
+ if_($has_plasma5, "$distro_config-kde4-config"),
if_($has_lxde, "mageia-lxde-config-$distro_release"),
if_($has_xfce, "mageia-xfce-config-$distro_release"),
@@ -258,10 +258,10 @@ $o = {
if_($has_gnome, 'gnome-shell', 'caribou', 'caribou-gtk3', 'brasero', 'gparted', 'gnome-classic-session', 'hexchat'),
- if_($has_kde4, 'kcm-touchpad',),
+ if_($has_plasma5, 'kcm-touchpad',),
],
- 'preferred_packages' => join(',', $has_kde4 ? 'kdm' : 'gdm'),
+ 'preferred_packages' => join(',', $has_plasma5 ? 'sddm' : 'gdm'),
'meta_class' => 'desktop',
'desktop' => first(@desktops),
if_($ENV{DRAKLIVE_DEFAULT_USER}, 'autologin' => $ENV{DRAKLIVE_DEFAULT_USER}),